@@ -55,6 +55,7 @@ KLinesScene::KLinesScene( QObject* parent )
 
     m_previewItem = new PreviewItem(this);
     m_previewItem->setPos( 0, 0 );
+    addItem(m_previewItem);
 
     m_popupItem = new KGamePopupItem;
     addItem(m_popupItem);
@@ -105,7 +106,7 @@ void KLinesScene::startNewGame()
         m_nextColors.append(c);
     }
 
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    emit stateChanged(QStringLiteral( "not_undoable" ));
 
     nextThreeBalls();
 }
@@ -600,7 +601,7 @@ void KLinesScene::saveUndoInfo()
     m_undoInfo.score = m_score;
     m_undoInfo.nextColors = m_nextColors;
 
-    emit stateChanged(QLatin1String( "undoable" ));
+    emit stateChanged(QStringLiteral( "undoable" ));
 }
 
 // Brings m_field and some other vars to the state it was before last turn
@@ -655,7 +656,7 @@ void KLinesScene::undo()
 
     emit scoreChanged(m_score);
 
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    emit stateChanged(QStringLiteral( "not_undoable" ));
 }
 
 void KLinesScene::drawBackground(QPainter *p, const QRectF&)
@@ -681,7 +682,7 @@ void KLinesScene::gameOverHandler()
         return; // don't emit twice
     m_gameOver = true;
     qDebug() << "GAME OVER";
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    emit stateChanged(QStringLiteral( "not_undoable" ));
     //emit enableUndo(false);
     emit gameOver(m_score);
 
